@@ -1,5 +1,6 @@
 #!/bin/sh -e
-
+CHECK=yes
+export CHECK
 . ./config.sh
 
 OCBOCAMLFLAGS=''
@@ -45,4 +46,4 @@ else
   do
     rule $i
   done
-fi
\ No newline at end of file
+fi
